%%%%%%%%%%%%%%%%%
%
% mozart0.tex
%
%%%%%%%%%%%%%%%%
\def\Lrp#1{\centerbar{\liftpause{#1}}}
\normalmusicsize%
\tracingstats=2\relax
\hsize=524pt
\vsize=740pt
\def\nbinstruments{2}
\setstaffs11
\setclef16
\setname1{ }
\setstaffs21
\setclef20
\setname2{ }
\generalsignature{ 0}%
\generalmeter\meterC%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\startpiece\addspace\afterruleskip%
\znotes&\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
% bar  1
\def\Notes{\vnotes1.41\elemskip}%
\def\NOtes{\vnotes2.00\elemskip}%
\NOtes\ibl1{'E}0\qb1C\qb1G\qb1E\tbl1\qb1G\ibl1E0\qb1C\qb1G\qb1E%
\tbl1\qb1G&\hl{'c}\sk\sk\sk\ql e\sk\ql g\en%
\let\Endpiece=\endpiece%
% bar  2
\xbar
\NOtes\ibl1{'F}0\qb1D\qb1G\qb1F&\qlp{'b}\en%
\Notes\tbl1\qb1{'G}&\ibbl2{'c}1\qb2c\tbl2\qb2d\en%
\NOtes\ibl1{'E}0\qb1C\qb1G\qb1E\tbl1\qb1G&\hl{'c}\en%
\Endpiece
